@@ -23,13 +23,13 @@ __all__ = [
 		]
 
 __copyright__ = """
-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "0.5.5"
-
+__version__ = "0.5.6"
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
 extras_require = {
-		"sphinx": ["sphinx>=3.0.3", "sphinx_toolbox>=1.4.0"], "all": ["sphinx>=3.0.3", "sphinx_toolbox>=1.4.0"]
+		"sphinx": ["sphinx<3.4.0,>=3.0.3", "sphinx-toolbox>=1.4.0"],
+		"all": ["sphinx<3.4.0,>=3.0.3", "sphinx-toolbox>=1.4.0"]
 		}
