@@ -88,12 +88,12 @@ from typing import Any, Dict, List, MutableMapping, Optional, Tuple, Type
 
 # 3rd party
 import attr
-from sphinx.application import Sphinx
-from sphinx.ext.autodoc import ClassDocumenter, Documenter
-from sphinx.pycode import ModuleAnalyzer
-from sphinx_toolbox import __version__
-from sphinx_toolbox.more_autosummary import PatchedAutoSummClassDocumenter
-from sphinx_toolbox.utils import Param, flag, parse_parameters, unknown_module_warning
+from sphinx.application import Sphinx  # nodep
+from sphinx.ext.autodoc import ClassDocumenter, Documenter  # nodep
+from sphinx.pycode import ModuleAnalyzer  # nodep
+from sphinx_toolbox import __version__  # nodep
+from sphinx_toolbox.more_autosummary import PatchedAutoSummClassDocumenter  # nodep
+from sphinx_toolbox.utils import Param, flag, parse_parameters, unknown_module_warning  # nodep
 
 # this package
 from attr_utils.docstrings import add_attrs_doc
@@ -117,8 +117,7 @@ class AttrsDocumenter(PatchedAutoSummClassDocumenter):
 	.. versionchanged:: 0.3.0
 
 		Added support for `autodocsumm <https://github.com/Chilipp/autodocsumm>`_.
-
-	"""
+	"""  # noqa: D400
 
 	objtype = "attrs"
 	directivetype = "class"
@@ -127,7 +126,7 @@ class AttrsDocumenter(PatchedAutoSummClassDocumenter):
 			**PatchedAutoSummClassDocumenter.option_spec,
 			"no-init-attribs": flag,
 			}
-	object: Type[AttrsClass]
+	object: Type[AttrsClass]  # noqa: A003  # pylint: disable=redefined-builtin
 
 	@classmethod
 	def can_document_member(cls, member: Any, membername: str, isattr: bool, parent: Any) -> bool:
@@ -164,14 +163,14 @@ class AttrsDocumenter(PatchedAutoSummClassDocumenter):
 
 	def _get_docstring(self) -> Tuple[Dict[str, Param], List[str], List[str]]:
 		"""
-		Returns params, pre_output, post_output
+		Returns params, pre_output, post_output.
 		"""
 
 		# Size varies depending on docutils config
-		tab_size = self.env.app.config.docutils_tab_width  # type: ignore
+		tab_size = self.env.app.config.docutils_tab_width
 
 		if self.object.__doc__:
-			docstring = dedent(self.object.__doc__).expandtabs(tab_size).split("\n")
+			docstring = dedent(self.object.__doc__).expandtabs(tab_size).split('\n')
 		else:
 			docstring = []
 
@@ -179,8 +178,7 @@ class AttrsDocumenter(PatchedAutoSummClassDocumenter):
 
 	def import_object(self, raiseerror: bool = False) -> bool:
 		"""
-		Import the object given by ``self.modname`` and ``self.objpath`` and set
-		it as ``self.object``.
+		Import the object given by ``self.modname`` and ``self.objpath`` and set it as ``self.object``.
 
 		If the object is an `attrs <https://www.attrs.org/>`__ class
 		:func:`attr_utils.docstrings.add_attrs_doc` will be called.
@@ -240,7 +238,7 @@ class AttrsDocumenter(PatchedAutoSummClassDocumenter):
 				doc = member_docstrings[field]
 
 			field_entry = [f":param {field}:", *doc]
-			parameter_docs.append(" ".join(field_entry))
+			parameter_docs.append(' '.join(field_entry))
 			all_docs[field] = ''.join(doc).strip()
 
 		self.add_line('', sourcename)
@@ -285,9 +283,7 @@ class AttrsDocumenter(PatchedAutoSummClassDocumenter):
 
 		:param members:
 		:param want_all:
-
-		:return:
-		"""
+		"""  # noqa: D400
 
 		attrib_names = (a.name for a in attr.fields(self.object) if a.init)
 
